@@ -11,7 +11,7 @@ use vars qw(@ISA $printCmd $defaultPrintCmd $VERSION);
 
 @ISA = qw(Tk::Derived Tk::Frame Tk::Multi::Any);
 
-$VERSION = sprintf "%d.%03d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 2.2 $ =~ /(\d+)\.(\d+)/;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -43,7 +43,7 @@ sub Populate
 
     my $titleLabel = $cw->Label(text => $title.' display')-> pack(qw/fill x/) ;
 
-    $menu->command(-label=>'print', command => [$cw, 'print' ]) ;
+    $menu->command(-label=>'print...', command => [$cw, 'print' ]) ;
     $menu->command(-label=>'clear', command => [$cw, 'clear' ]);
 
     # print stuff
